@@ -17,19 +17,26 @@ var (
 		"host-network",
 		"host-pid",
 		"invalid-target-ports",
+		"job-ttl-seconds-after-finished",
 		"latest-tag",
+		"liveness-port",
 		"mismatching-selector",
 		"no-anti-affinity",
 		"no-extensions-v1beta",
 		"no-read-only-root-fs",
 		"non-existent-service-account",
+		"pdb-max-unavailable",
+		"pdb-min-available",
 		"privilege-escalation-container",
 		"privileged-container",
+		"readiness-port",
 		"run-as-non-root",
 		"sensitive-host-mounts",
 		"ssh-port",
+		"startup-port",
 		"unsafe-sysctls",
 		"unset-cpu-requirements",
 		"unset-memory-requirements",
+		"pdb-unhealthy-pod-eviction-policy",
 	)
 )
