@@ -4,6 +4,7 @@ import (
 	// Import all check templates.
 	_ "golang.stackrox.io/kube-linter/pkg/templates/accesstoresources"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/antiaffinity"
+	_ "golang.stackrox.io/kube-linter/pkg/templates/cel"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/clusteradminrolebinding"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/containercapabilities"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/cpurequirements"
@@ -60,6 +61,7 @@ import (
 	_ "golang.stackrox.io/kube-linter/pkg/templates/targetport"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/unsafeprocmount"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/updateconfig"
+	_ "golang.stackrox.io/kube-linter/pkg/templates/volumeclaimtemplates"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/wildcardinrules"
 	_ "golang.stackrox.io/kube-linter/pkg/templates/writablehostmount"
 )
